import { MinimalButton, Spinner, Viewer } from '@react-pdf-viewer/core';
import {
    Match,
    NextIcon,
    PreviousIcon,
    RenderHighlightsProps,
    RenderSearchProps,
    SearchPlugin,
    searchPlugin,
} from '@react-pdf-viewer/search';
import * as React from 'react';

enum SearchStatus {
    NotSearchedYet,
    Searching,
    FoundResults,
}

interface SearchSidebarInnerProps {
    renderSearchProps: RenderSearchProps;
    searchPluginInstance: SearchPlugin;
}

const SearchSidebarInner: React.FC<SearchSidebarInnerProps> = ({ renderSearchProps, searchPluginInstance }) => {
    const [searchStatus, setSearchStatus] = React.useState(SearchStatus.NotSearchedYet);
    const [matches, setMatches] = React.useState<Match[]>([]);

    const { currentMatch, keyword, jumpToMatch, jumpToNextMatch, jumpToPreviousMatch } = renderSearchProps;

    const renderMatchSample = (match: Match) => {
        //  match.startIndex    match.endIndex
        //      |                       |
        //      ▼                       ▼
        //  ....[_____props.keyword_____]....

        const wordsBefore = match.pageText.substr(match.startIndex - 20, 20);
        let words = wordsBefore.split(' ');
        words.shift();
        const begin = words.length === 0 ? wordsBefore : words.join(' ');

        const wordsAfter = match.pageText.substr(match.endIndex, 60);
        words = wordsAfter.split(' ');
        words.pop();
        const end = words.length === 0 ? wordsAfter : words.join(' ');

        return (
            <div>
                {begin}
                <span style={{ backgroundColor: 'rgb(255, 255, 0)' }}>
                    {match.pageText.substring(match.startIndex, match.endIndex)}
                </span>
                {end}
            </div>
        );
    };

    const performSearch = () => {
        setSearchStatus(SearchStatus.Searching);
        searchPluginInstance.search().then((matches) => {
            setSearchStatus(SearchStatus.FoundResults);
            setMatches(matches);
        });
    };
    console.log('kr', keyword);

    // const handleSearchKeyDown = (e: React.KeyboardEvent) => {
    //     console.log('call');
    //     if (e.key === 'Enter') {
    //         performSearch();
    //     }
    // };

    console.log('matches', matches);

    return (
        <div
            style={{
                display: 'flex',
                flexDirection: 'column',
                height: '100%',
                overflow: 'hidden',
                width: '100%',
            }}
        >
            <div style={{ padding: '.5rem' }}>
                <div style={{ position: 'relative' }}>
                    <button
                        // placeholder="Enter to search"
                        // testId="keyword-input"
                        // value={keyword}
                        onClick={() => {
                            console.log('hello!');
                            searchPluginInstance.setKeyword([
                                { query: 'winter', colorCode: '#1476D7' },
                                { query: 'news', colorCode: '#E55184' },
                            ]);
                            performSearch();
                        }}
                        // onKeyDown={handleSearchKeyDown}
                    >
                        button
                    </button>
                    {searchStatus === SearchStatus.Searching && (
                        <div
                            style={{
                                alignItems: 'center',
                                display: 'flex',
                                bottom: 0,
                                position: 'absolute',
                                right: '.5rem',
                                top: 0,
                            }}
                        >
                            <Spinner size="1.5rem" />
                        </div>
                    )}
                </div>
            </div>
            {searchStatus === SearchStatus.FoundResults && (
                <>
                    {matches.length === 0 && 'Not found'}
                    {matches.length > 0 && (
                        <>
                            <div
                                style={{
                                    alignItems: 'center',
                                    display: 'flex',
                                    padding: '.5rem',
                                }}
                            >
                                <div
                                    data-testid="num-matches"
                                    style={{
                                        color: 'rgba(0, 0, 0, .5)',
                                        fontSize: '.8rem',
                                        marginRight: '.5rem',
                                    }}
                                >
                                    Found {matches.length} results
                                </div>
                                <div style={{ marginLeft: 'auto', marginRight: '.5rem' }}>
                                    <MinimalButton onClick={jumpToPreviousMatch}>
                                        <PreviousIcon />
                                    </MinimalButton>
                                </div>
                                <MinimalButton onClick={jumpToNextMatch}>
                                    <NextIcon />
                                </MinimalButton>
                            </div>
                            <div
                                style={{
                                    borderTop: '1px solid rgba(0, 0, 0, .2)',
                                    flex: 1,
                                    overflow: 'auto',
                                    padding: '.5rem 1rem',
                                }}
                            >
                                {matches.map((match, index) => (
                                    <div key={index} style={{ margin: '1rem 0' }}>
                                        <div
                                            style={{
                                                display: 'flex',
                                                justifyContent: 'space-between',
                                                marginBottom: '.5rem',
                                            }}
                                        >
                                            <div>#{index + 1}</div>
                                            <div
                                                style={{
                                                    color: 'rgba(0, 0, 0, .5)',
                                                    fontSize: '.8rem',
                                                    textAlign: 'right',
                                                }}
                                            >
                                                Page {match.pageIndex + 1}
                                            </div>
                                        </div>
                                        <div
                                            data-testid={`match-${index}`}
                                            style={{
                                                backgroundColor: currentMatch === index + 1 ? 'rgba(0, 0, 0, .1)' : '',
                                                border: '1px solid rgba(0, 0, 0, .2)',
                                                borderRadius: '.25rem',
                                                cursor: 'pointer',
                                                overflowWrap: 'break-word',
                                                padding: '.5rem',
                                            }}
                                            onClick={() => jumpToMatch(index + 1)}
                                        >
                                            {renderMatchSample(match)}
                                        </div>
                                    </div>
                                ))}
                            </div>
                        </>
                    )}
                </>
            )}
        </div>
    );
};

const SearchSidebar: React.FC<{
    searchPluginInstance: SearchPlugin;
}> = ({ searchPluginInstance }) => {
    const { Search } = searchPluginInstance;
    return (
        <Search>
            {(renderSearchProps: RenderSearchProps) => (
                <SearchSidebarInner renderSearchProps={renderSearchProps} searchPluginInstance={searchPluginInstance} />
            )}
        </Search>
    );
};

const IndexPage = () => {
    const searchPluginInstance = searchPlugin({
        renderHighlights: React.useCallback((renderProps: RenderHighlightsProps) => {
            const containerRefs = React.useRef<(HTMLDivElement | null)[]>([]);

            React.useEffect(() => {
                const firstHighlightEle = containerRefs.current[0];
                if (firstHighlightEle) {
                    // Perform actions like triggering a callback with the first element's details
                    const temp = () => ({
                        highlightEle: firstHighlightEle,
                        keyword: renderProps.highlightAreas[0]?.keyword,
                    });
                    temp();
                }
            }, [renderProps.highlightAreas]);

            return (
                <>
                    {console.log('renderProps', renderProps)}
                    {renderProps.highlightAreas.map((area, index) => (
                        <div
                            key={index}
                            // className={styles.highlight}
                            data-index={index}
                            ref={(el) => (containerRefs.current[index] = el)} // Store each ref in the array
                            style={{
                                left: `${area.left}%`,
                                top: `${area.top}%`,
                                height: `${area.height}%`,
                                width: `${area.width}%`,
                                backgroundColor: `${area.color}`, // Use template literal for hsl
                                // borderRadius: '4px', // Use camelCase for inline styles
                                position: 'absolute', // Use camelCase for inline styles
                                zIndex: 1, // Use camelCase for inline styles
                                opacity: 0.5,
                            }}
                            title={area.keywordStr.trim()}
                        />
                    ))}
                </>
            );
        }, []), // Ensure onHighlightKeyword is in the dependency array
    });

    return (
        <div
            style={{
                border: '1px solid rgba(0, 0, 0, .3)',
                display: 'flex',
                height: '50rem',
                margin: '5rem auto',
                width: '64rem',
            }}
        >
            <div
                style={{
                    borderRight: '1px solid rgba(0, 0, 0, .2)',
                    flex: '0 0 15rem',
                    width: '15rem',
                }}
            >
                <SearchSidebar searchPluginInstance={searchPluginInstance} />
            </div>

            <div style={{ flex: 1 }}>
                <Viewer fileUrl="/pkpadmin,+1135-5265-1-CE.pdf" plugins={[searchPluginInstance]} />
            </div>
        </div>
    );
};

export default IndexPage;
